#
# spec file for package hydrogen
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soversion 1
%bcond_with lash
# The use of librubberband2 is marked as experimental.
# Because the current implementation produce wrong timing!
# So long this bug isn't solved, please disable this option.
# If rubberband-cli is installed, the hydrogen rubberband-function
# will work properly as expected.
%bcond_with librubberband

Name:           hydrogen
Version:        1.0.1
Release:        bp153.1.18
Summary:        A Real-Time Drum Machine and Sequencer
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Midi
URL:            http://www.hydrogen-music.org/
Source0:        https://github.com/hydrogen-music/hydrogen/archive/%{version}/%{name}-%{version}.tar.gz
Patch0:         fix-version-soversion.patch
Patch1:         fix-obsolete-appdata.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  help2man
BuildRequires:  hicolor-icon-theme
BuildRequires:  ladspa
BuildRequires:  ladspa-devel
BuildRequires:  libtar-devel
BuildRequires:  pkgconfig
BuildRequires:  portmidi-devel
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core) >= 5.6
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  cmake(Qt5XmlPatterns)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(liblo)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(lrdf)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(raptor2)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(zlib)
%if 0%{?suse_version} <= 1500
BuildRequires:  gcc9
BuildRequires:  gcc9-c++
%else
BuildRequires:  gcc-c++
%endif
%if %{with lash}
BuildRequires:  pkgconfig(lash-1.0)
%endif
%if %{with librubberband}
BuildRequires:  pkgconfig(rubberband)
%else
BuildRequires:  rubberband-cli
Requires:       rubberband-cli
%endif

%description
Hydrogen is a software synthesizer which can be used alone, emulating
a drum machine based on patterns, or via an external MIDI
keyboard/sequencer software.

It features a modular and graphical interface based on QT4, has a
sample-based stereo audio engine, with import of sound samples in PCM
formats. Furthermore, a pattern-based sequencer with the ability to
chain patterns into a song. Up to 64 ticks per pattern with
individual level per event and variable pattern length are possible.
32 instrument tracks with volume, mute, solo, pan capabilities are
provided, and there is multi-layer support for instruments (up to 16
samples for each instrument). Human velocity, human time, pitch and
swing functions are implemented as well.

%package -n libhydrogen-core%{soversion}
Summary:        Library essential for the hydrogen drum machine software
Group:          System/Libraries

%description -n libhydrogen-core%{soversion}
Hydrogen is a software synthesizer which can be used alone, emulating
a drum machine based on patterns, or via an external MIDI
keyboard/sequencer software.

This library is the core of hydrogen's operation.

%package -n libhydrogen-core-devel
Summary:        Development files and headers for libhydrogen-core
Group:          Development/Libraries/C and C++
Requires:       libhydrogen-core%{soversion} = %{version}

%description -n libhydrogen-core-devel
These are the headers needed to develop apps that
link with libhydrogen-core.

%prep
%autosetup -p1

%build
export LADSPA_PATH=%{_libdir}/ladspa

%cmake \
%if 0%{?suse_version} <= 1500
	-DCMAKE_C_COMPILER=gcc-9 \
	-DCMAKE_CXX_COMPILER=g++-9 \
%endif
%if %{with lash}
	-DWANT_LASH:BOOL=ON \
%endif
	-DWANT_LIBARCHIVE:BOOL=ON \
	-DWANT_LRDF:BOOL=ON \
	-DWANT_PORTAUDIO:BOOL=ON \
	-DWANT_PORTMIDI:BOOL=ON \
%if %{with librubberband}
	-DWANT_RUBBERBAND:BOOL=ON \
%endif
	-DWANT_SHARED:BOOL=ON

%cmake_build

%install
%cmake_install

# Install the h2cli man page created by help2man
install -d -m 0755 %{buildroot}%{_mandir}/man1
LD_LIBRARY_PATH=%{buildroot}%{_libdir} \
	help2man -N -o %{buildroot}%{_mandir}/man1/h2cli.1 %{buildroot}%{_bindir}/h2cli

%suse_update_desktop_file -i org.hydrogenmusic.Hydrogen AudioVideo Sequencer

%fdupes -s %{buildroot}%{_datadir}

%find_lang %{name} --with-qt

%files -f %{name}.lang
%license COPYING
%doc AUTHORS ChangeLog README.txt
%{_bindir}/*
%{_datadir}/%{name}
%{_datadir}/applications/org.hydrogenmusic.Hydrogen.desktop
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%{_datadir}/metainfo/org.hydrogenmusic.Hydrogen.appdata.xml
%{_mandir}/man1/h2cli.1%{?ext_man}
%{_mandir}/man1/hydrogen.1%{?ext_man}

%post -n libhydrogen-core%{soversion} -p /sbin/ldconfig
%postun -n libhydrogen-core%{soversion} -p /sbin/ldconfig

%files -n libhydrogen-core%{soversion}
%{_libdir}/libhydrogen-core.so.*

%files -n libhydrogen-core-devel
%{_includedir}/%{name}
%{_libdir}/libhydrogen-core.so

%changelog
* Sun Nov 15 2020 munix9@googlemail.com
- Update to version 1.0.1
  * Fixed compilation with libtar
  * Fixed jack transport tempo drift when using non-integer bpm values
  * Disabled "development mode" warning
  * Fix crash on saving ladspa settings
  * Added manual + tutorial files to Windows and OS X Installers
- Update to version 1.0.0
  * QT5 support
  * MIDI feedback
  * OSC support (incl. feedback)
  * Playback track
  * Menu redesign
  * Note probability property
  * Velocity automation
  * Full screen mode
  * New default kit: GMRockKit
- Add fix-obsolete-appdata.patch
- Add fix-version-soversion.patch (replaces hydrogen-0.9.6-lib64.patch)
- Remove hydrogen-no-current-time.patch (__DATE__ and __TIME__
  are considered by SOURCE_DATE_EPOCH and the compiler)
- Remove hydrogen-fix-qt5.15.patch (fixed upstream)
- Remove hydrogen-gcc47.patch (obsolete)
- Remove hydrogen-0.9.6-lib64.patch (obsolete)
- h2cli.1 is now created during %%install
- Clean up spec file
* Wed Jun  3 2020 davejplater@gmail.com
- Update to version 0.99+git20200527 and fix factory build against
  qt 5.15 with hydrogen-fix-qt5.15.patch
- Remove incorporated patches:
  hydrogen-ongEditorPanel-clean-up-scroll-signals.patch,
  hydrogen-SongEditorPanel-Add-methods-to-show-Timeline-Playbac.patch
  and hydrogen-SongEditor-Fix-timeline-scrolling.patch
- Upstream changes:
  * Fix buffer and period size calculation
  * hydrogen.cpp: change return value behavior of audioEngine_process()
  * Fix prefs dialog buffersize driver restart message
  * Fail gracefully on failure to set ALSA period (Fix #879)
  * Bugfix for #857: Check audioEngine_process() ret. value when exporting
  * Do not update specific UI parts if song export is active  (see #857)
  * More smaller fixes which address compiler warnings..
  * ExportMidiDialog: initialize pSmfWriter
  * Fix #874 - improve scrolling to newly selected pattern (#875)
* Wed Feb 12 2020 Stefan Dirsch <sndirsch@suse.com>
- hydrogen-ongEditorPanel-clean-up-scroll-signals.patch,
  hydrogen-SongEditorPanel-Add-methods-to-show-Timeline-Playbac.patch,
  hydrogen-SongEditor-Fix-timeline-scrolling.patch,
  * adjusted git commits from upstream, which fix scrolling in
    Song Editor (boo#1163519)
* Sun Apr  7 2019 plater <davejplater@gmail.com>
- Update to 1.0.0-beta named version 0.9.9pre1
- Now builds with qt5
- Rebased hydrogen-0.9.6-lib64.patch, hydrogen-gcc47.patch and
  hydrogen-no-current-time.patch.
- Removed hydrogen-0.9.6-desktop.patch.
* Wed Mar  7 2018 davejplater@gmail.com
- Remove lash dependency and enable pulse audio support.
* Wed Apr 12 2017 davejplater@gmail.com
- Modified hydrogen-no-current-time.patch to remove all references
  to current date and time.
* Wed Jan 25 2017 jengelh@inai.de
- Trim description and fix all the incomplete sentences.
* Thu Jan 12 2017 wbauer@tmo.at
- Update to version 0.9.7, adapt patches
- Drop hydrogen.1 source file, move the included man page to the
  right place instead of installing our own version
- Updated h2cli.1 man page
- Use desktop-file-utils macros instead of update-desktop-database
- Upstream changes:
  * The color of the SongEditors squares is now configurable
  * Added support for midi cymbal choking
  * Added support for midi hihat pressure control
  * Added hihat pressure groups
  * Added basic non session manager support
  * Added instrument components
  * Basic lilypond export
  * New windows cross compilation script
  * Support for soundlibrary images
  * Configurable sample selection algorithm
  * Support for soundlibraries with images
  * New midi action:
  * SELECT_PREV_PATTERN_RELATIVE
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun scripts
* Fri Sep  5 2014 wbauer@tmo.at
- Update to final version 0.9.6, adapt patches
- Changed hydrogen-0.9.6-desktop.patch to not add quotes to the
  german Name and GenericName entries in the .desktop file, this
  doesn't really make sense and looks bad in the application menu
- Updated h2cli.1 and hydrogen.1 man pages
- Upstream changes (compared to 0.9.5):
  * Release 0.9.6
  * new build system (cmake)
  * add undo for song/pattern editor
  * jack-session support
  * jack-midi support
  * several bug fixes
  * tabbed interface
  * several small changes to the GUI
  * improve ExportSong add use of TimeLineBPM,
    RubberbandBatch processor and different types of resample interpolation
* Sat Nov 23 2013 wbauer@tmo.at
- Update to version 0.9.6-beta3, adapt patches
- Upstream changes:
  * Release 0.9.6
  * new build system (cmake)
  * add undo for song/pattern editor
  * jack-session support
  * jack-midi support
  * several bug fixes
  * tabbed interface
  * several small changes to the GUI
  * improve ExportSong add use of TimeLineBPM,
    RubberbandBatch processor and different types of resample interpolation
* Sun Jun  2 2013 andreas.stieger@gmx.de
- remove build requirements subversion and rsync
* Sat Mar 17 2012 boris@steki.net
- Add hydrogen-gcc47.patch: Fix build with gcc 4.7.
* Tue Oct 25 2011 coolo@suse.com
- fix another link into %%buildroot
* Fri Oct 14 2011 davejplater@gmail.com
- Changed build to release due to the default debug build being
  sluggish.
* Tue Oct 11 2011 davejplater@gmail.com
- Gave libhydrogen-core.so a SONAME and fixed the <= 11.4 build
  which needed Qt webkit to have QtXmlPatterns with
  BuildRequires: pkgconfig(QtXmlPatterns)
* Wed Oct  5 2011 davejplater@gmail.com
- Update to version 0.9.6, all patches obsolete, remade
  hydrogen-no-current-time.patch & hydrogen-0.9.6-desktopfile.patch
- Build system now uses cmake, rewrote the Build section and added
  man page for h2cli. Created devel and libhydrogen-core-0_9_6-0
  sub packages.
- Upstream changes :
  * Release 0.9.6
  * new build system (cmake)
  * add undo for song/pattern editor
  * jack-session support
  * some bug fixes
* Sun Aug 14 2011 ro@suse.de
- make it build even if python reports platform as linux3
* Fri Mar 18 2011 davejplater@gmail.com
- Update to Version 0.9.5 added portaudio.patch from upstream.
- Made hydrogen-no-current-time.patch use __TIMESTAMP__ instead of
  __DATE__
- No more kde3 dependency since version 0.9.4, now uses Qt4.
- Added man page created with hepl2man.
- Added hydrogen-0.9.5-desktopfile.patch which replaces
  linux/hydrogen.desktop file which is installed with the one in
  the top source directory.
- Upstream changes :
  * load playlists at startup
  * midi-learn works now with shift-click on some gui elements
  * multi-track export and LADI support
  * maximum number of bars is now configurable
  * added czech translation
  * fixed serveral export song failures
  * added ogg, flac, aiff export support
  * added some new commandline parameter for no_gui version
  * added rubberband-cli support
  * several improvements on sample editor
  * added support for app bundles on OSX
  * non destructive sample editor
  * piano roll editor and instrument midi out
  * destructive midi recording and added czech translation
  * support for midi "note off" messages & virtual patterns
  * time line to change song tempo and add tags
  * director and at least several small changes
  * Xml handling is now done by QtXml instead of TinyXML
  * improved support for non-ascii filenames / strings
  * remove direct dependencies to libflac
- For earlier 0.9.4 changes see ChangeLog
* Fri Mar 26 2010 coolo@novell.com
- disable parallel make to avoid the random failures we see
* Mon May 18 2009 tiwai@suse.de
- fix build with gcc 4.4; add missing stdio.h inclusions
* Mon Oct 22 2007 tiwai@suse.de
- fix build with gcc 4.3
* Mon Jun  4 2007 dmueller@suse.de
- remove FLAC 1.1.4 patch for < 10.3
* Mon May  7 2007 stbinner@suse.de
- fix build on < 10.3
* Thu May  3 2007 wstephenson@suse.de
- fix buildrequires: libraptor1-devel -> libraptor-devel
* Thu May  3 2007 lrupp@suse.de
- fix buildrequires: raptor-devel -> libraptor1-devel
* Mon Apr 16 2007 tiwai@suse.de
- fix build with FLAC 1.1.4.
* Thu Jan 18 2007 tiwai@suse.de
- use RPM_OPT_FLAGS for plugins.
* Mon Jul 31 2006 tiwai@suse.de
- updated to version 0.9.3:
  * mostly bugfixes, including memory leak (#194576)
  * new plugins
* Thu Jun 15 2006 dmueller@suse.de
- build parallel
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct 18 2005 tiwai@suse.de
- fixed for gcc 4.1.
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Wed Jul 27 2005 tiwai@suse.de
- updated to version 0.9.2.
* Wed May 11 2005 schwab@suse.de
- Fix library order.
- Fix broken cast.
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Fri Jan 21 2005 tiwai@suse.de
- updated to version 0.9.1.
* Thu Dec 16 2004 coolo@suse.de
- tried to fix Makefiles, but disabled unsermake in the middle
* Wed Aug 25 2004 mana@suse.de
- update to 0.8.2 (non-beta)
* Mon Aug 16 2004 ro@suse.de
- run update_admin
* Tue Mar  2 2004 tiwai@suse.de
- updated to version 0.8.2beta1.
* Fri Feb 20 2004 tiwai@suse.de
- fixed the installation of desktop file.
* Wed Jan 14 2004 tiwai@suse.de
- updated to version 0.8.1.
  libhydrogen is merged again.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Sep 19 2003 tiwai@suse.de
- fixed the desktop icon path.
* Mon Sep 15 2003 tiwai@suse.de
- added desktop icons.
* Fri Aug 29 2003 tiwai@suse.de
- added %%run_ldconfig.
- fixed categories.
* Thu Aug 28 2003 tiwai@suse.de
- fixed the change of types in the recent JACK.
* Thu Aug 14 2003 tiwai@suse.de
- added desktop file.
* Mon Jul  7 2003 tiwai@suse.de
- updated to version 0.8.0.
* Tue Apr  1 2003 tiwai@suse.de
- initial version: 0.7.6.
